Struct TryCurrentError
pub struct TryCurrentError {
kind: TryCurrentErrorKind,
}Expand description
Error returned by try_current when no Runtime has been started
Fields
kind: TryCurrentErrorKindImplementations
impl TryCurrentError
impl TryCurrentError
pub fn is_missing_context(&self) -> bool
pub fn is_missing_context(&self) -> bool
Returns true if the call failed because there is currently no runtime in the Tokio context.
pub fn is_thread_local_destroyed(&self) -> bool
pub fn is_thread_local_destroyed(&self) -> bool
Returns true if the call failed because the Tokio context thread-local had been destroyed. This can usually only happen if in the destructor of other thread-locals.